import sys

from qtpy import QtWidgets

from pyqtribbon import RibbonBar, RibbonCategoryStyle


def test_filemenu():
    if __name__ == "__main__":
        app = QtWidgets.QApplication(sys.argv)
        # Central widget
        window = QtWidgets.QMainWindow()

        # Ribbon bar
        ribbonbar = RibbonBar()
        window.setMenuBar(ribbonbar)

        categories1 = ribbonbar.addCategoriesBy(
            {
                "Category 6": {
                    "style": RibbonCategoryStyle.Normal,
                    "panels": {
                        "Panel 1": {
                            "showPanelOptionButton": True,
                            "widgets": {
                                "Button 1": {
                                    "type": "Button",
                                    "arguments": {
                                        "text": "Button",
                                        "tooltip": "This is a tooltip",
                                    },
                                },
                                "Button 2": {
                                    "type": "Button",
                                    "arguments": {
                                        "text": "Button 2",
                                        "tooltip": "This is a tooltip",
                                    },
                                },
                            },
                        },
                        "Panel 2": {
                            "showPanelOptionButton": False,
                            "widgets": {
                                "Button 3": {
                                    "type": "Button",
                                    "arguments": {
                                        "text": "Button 3",
                                        "tooltip": "This is a tooltip",
                                    },
                                },
                                "Button 4": {
                                    "type": "Button",
                                    "arguments": {
                                        "text": "Button 4",
                                        "tooltip": "This is a tooltip",
                                    },
                                },
                            },
                        },
                    },
                }
            }
        )

        assert categories1["Category 6"].title() == "Category 6"
        assert categories1["Category 6"].categoryStyle() == RibbonCategoryStyle.Normal
        assert categories1["Category 6"].panels()["Panel 1"].title() == "Panel 1"
        assert categories1["Category 6"].panels()["Panel 1"]._showPanelOptionButton
        assert categories1["Category 6"].panels()["Panel 1"].widgets()[0].text() == "Button"
        assert categories1["Category 6"].panels()["Panel 1"].widgets()[0].toolTip() == "This is a tooltip"
        assert categories1["Category 6"].panels()["Panel 1"].widgets()[1].text() == "Button 2"
        assert categories1["Category 6"].panels()["Panel 1"].widgets()[1].toolTip() == "This is a tooltip"
        assert categories1["Category 6"].panels()["Panel 2"].title() == "Panel 2"
        assert not categories1["Category 6"].panels()["Panel 2"]._showPanelOptionButton
        assert categories1["Category 6"].panels()["Panel 2"].widgets()[0].text() == "Button 3"
        assert categories1["Category 6"].panels()["Panel 2"].widgets()[0].toolTip() == "This is a tooltip"
        assert categories1["Category 6"].panels()["Panel 2"].widgets()[1].text() == "Button 4"
        assert categories1["Category 6"].panels()["Panel 2"].widgets()[1].toolTip() == "This is a tooltip"

        # Show the window
        window.resize(1800, 350)
        window.show()
        sys.exit(app.exec_())



import sys

from qtpy import QtWidgets

from pyqtribbon import RibbonBar
from pyqtribbon.panel import RibbonPanel
from pyqtribbon.toolbutton import RibbonToolButton


def test_categories():
    if __name__ == "__main__":
        app = QtWidgets.QApplication(sys.argv)
        # Central widget
        window = QtWidgets.QMainWindow()

        # Ribbon bar
        ribbonbar = RibbonBar()
        window.setMenuBar(ribbonbar)

        categories = ribbonbar.addContextCategories("name", ["Context 1", "Context 2"])
        assert isinstance(categories, dict)
        assert len(categories) == 2
        assert categories["Context 1"].title() == "Context 1"
        assert categories["Context 2"].title() == "Context 2"

        panel1 = categories["Context 1"].addPanel("Context 1 Panel 1")
        button1 = panel1.addLargeButton("Button 1")
        assert isinstance(panel1, RibbonPanel)
        assert panel1.title() == "Context 1 Panel 1"
        assert isinstance(button1, RibbonToolButton)
        assert button1.text() == "Button 1"

        panel2 = categories["Context 2"].addPanel("Context 2 Panel 1")
        button2 = panel2.addLargeButton("Button 2")
        assert isinstance(panel2, RibbonPanel)
        assert panel2.title() == "Context 2 Panel 1"
        assert isinstance(button2, RibbonToolButton)
        assert button2.text() == "Button 2"

        # Show the window
        window.resize(1800, 350)
        window.show()
        sys.exit(app.exec_())
